Compute Separation Efficiency — BAGO 0.0.1 documentation

# Compute Separation Efficiency

sepEfficiency(rtSeq, rtRange)

  Calculate the separation efficiency using a series of retention times.

  Parameters:

    - rtSeq – numpy array. Retention times of the top features.

    - rtRange – numpy array. Times when gradient begins and ends. In minute.

  Returns:

    float. Separation efficiency.

To use this function:

    sep_eff = sepEfficiency(rtSeq, rtRange)
    print('Separation efficiency: %.2f' % sep_eff)